//
//  AudioOutput.h
//  AudioBoard
//  This code is released under the BSD License
//  Copyright (c) 2013 retronyms. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <AudioUnit/AudioUnit.h>
#ifdef AUDIOBUS
#import "Audiobus.h"
#endif
@protocol AudioIODelegate
- (void)interAppConnected;
- (void)interAppDisconnected;
- (void)interAppTransportChanged;
@end
@interface AudioIO : NSObject
{
    NSString *name;
    AudioComponentDescription componentDescription;
    id<AudioIODelegate> delegate;
    AudioBufferList *lastInputBuffer;
    AudioComponentInstance remoteIOUnit;
    BOOL interAppConnected;
    BOOL inForeground;
    BOOL isPlaying;
    BOOL isRecording;
    Float64 outCurrentSampleInTimeLine;
#ifdef AUDIOBUS
    ABOutputPort               *audiobusOutput;
    ABInputPort                *audiobusInput;
    ABAudiobusController       *audiobusController;
    ABAudiobusAudioUnitWrapper *audiobusAudioUnitWrapper;
#endif
    CFAbsoluteTime lastCallbackTime;
    float cpuPercent;

}
@property (readonly) float cpuPercent;
@property (readonly) UIImage *hostIcon;
@property (readonly) BOOL isPlaying;
@property (readonly) BOOL isRecording;
@property (readonly) BOOL interAppConnected;
@property (readonly) Float64 currentSample;
@property (readwrite,assign) id<AudioIODelegate> delegate;
#ifdef AUDIOBUS
@property (readonly) ABOutputPort* audiobusOutput;
@property (readonly) ABInputPort* audiobusInput;
@property (readonly) ABAudiobusController* audiobusController;
@property (readonly) ABAudiobusAudioUnitWrapper* audiobusAudioUnitWrapper;
#endif
- (id)initWithAudioComponentDescription:(AudioComponentDescription)desc name:(NSString*)name;
+ (BOOL)interAppReady;
+ (void)setAudioSessionActive;
- (void)toggleInterAppPlay;
- (void)toggleInterAppRecord;
- (void)startIO:(BOOL)publish;
- (void)activateAudiobus:(NSString*)apikey url:(NSString*)launchurl;
- (void) gotoHost;
@end
